<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\Models\User;
use App\Models\UserAction;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'first_name' => ['required', 'string', 'max:255'],
            'last_name' => ['required', 'string', 'max:255'],
            'username' => ['required', 'string', 'max:255'],
            'phone' => ['required', 'string', 'max:20'],
            'city' => ['required', 'string', 'max:255'],
            'address_one' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    protected function redirectTo()
    {
        if (Auth::user()->user_type == 'Admin') {
            return route('admin.applications.queue' );
        }
        else if (Auth::user()->user_type == 'volunteer') {
            return route('volunteer.apply.index');
        }
        else if (Auth::user()->user_type == 'client') {
            return route('client.referal.index');
        }
        else if (Auth::user()->user_type == 'caregiver') {
            return route('caregiver.referal.index');
        }
        // return '/home';
    }
    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    protected function create(array $data)
    {
        
        $user =  User::create([
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'phone' => $data['phone'],
            'address_one' => $data['address_one'],
            'address_two' => $data['address_two'],
            'city' => $data['city'],
            'postal_code' => $data['postal_code'],
            'uname' => $data['username'],
            'user_type' =>$data['user_type'],
            'status' =>1,
            'referal_id'=>0,
            'password' => Hash::make($data['password']),
        ]);
        UserAction::create([
            'first_name' => $data['first_name'],
            'last_name' => $data['last_name'],
            'email' => $data['email'],
            'phone' => $data['phone'],
            'address_one' => $data['address_one'],
            'address_two' => $data['address_two'],
            'city' => $data['city'],
            'postal_code' => $data['postal_code'],
            'username' => $data['username'],
            'user_type' =>$data['user_type'],
            'created_by' =>$user->id,
            'user_id' =>$user->id,
            'act_abbreviation' => 'created',
            'password' => Hash::make($data['password']),
        ]);

        return $user;
    }
}
